@@ -22,11 +22,14 @@
 #include <string.h> 
 #include <avr/eeprom.h> 
 
+#define SWVERSION "ver: ddcp-0.4.4"
+
 static int set_val[2];
 static int measured_val[2];
 static char i2c_buf[MAX_BUF_LEN+1];
 // the set values but converted to ADC steps
 static int set_val_adcUnits[2]; 
+static unsigned char bpress=0;
 
 void delay_ms(unsigned char ms)
 /* delay for a minimum of <ms> */
@@ -150,13 +153,20 @@ static void store_permanent(void){
 		eeprom_write_word((uint16_t *)0x02,set_val[0]);
 		eeprom_write_word((uint16_t *)0x04,set_val[1]);
 	}else{
-		lcd_puts_P("already stored");
+		if (bpress> 5){
+			// display software version after long press
+			lcd_puts_P(SWVERSION);
+			lcd_gotoxy(0,1);
+			lcd_puts_P("tuxgraphics.org");
+		}else{
+			lcd_puts_P("already stored");
+		}
 	}
-	delay_ms(250);
+	delay_ms(200);
 }
 
 // check the keyboard
-static signed char check_buttons(void){
+static unsigned char check_buttons(void){
 	if (check_u_button(&(set_val[1]))){
 		if(set_val[1]>U_MAX){
 			set_val[1]=U_MAX;
@@ -171,7 +181,7 @@ static signed char check_buttons(void){
 	}
 	if (check_store_button()){
 		store_permanent();
-		return(1);
+		return(2);
 	};
 	return(0);
 }
@@ -281,16 +291,25 @@ void main(void)
 
 		// the buttons must be responsive but they must not 
 		// scroll too fast if pressed permanently
-		if (!check_buttons()){
+		if (check_buttons()==0){
 			// no buttons pressed
 			delay_ms(100);
+			bpress=0;
 			check_i2c_interface();
 			check_buttons();
-			delay_ms(100);
+			delay_ms(150);
 		}else{
-			delay_ms(100);
-			check_i2c_interface();
-			delay_ms(100);
+			if (bpress > 11){
+				// somebody pressed permanetly the button=>scroll fast
+				delay_ms(10);
+				check_i2c_interface();
+				delay_ms(40);
+			}else{
+				bpress++;
+				delay_ms(100);
+				check_i2c_interface();
+				delay_ms(150);
+			}
 		}
 	}
 }
